@@ -592,7 +592,7 @@ class BatchLine(ModelSQL, ModelView):
                 self.contra_account = self.invoice.account.id
 
     @fields.depends('date', 'fiscalyear', 'journal', 'account',
-        'contra_account', 'batch')
+        'contra_account', 'batch', '_parent_batch.id')
     def on_change_date(self):
         pool = Pool()
         Fiscalyear = pool.get('account.fiscalyear')
@@ -625,7 +625,8 @@ class BatchLine(ModelSQL, ModelView):
             if fiscalyear_for_date != context['fiscalyear']:
                 self.date = None
 
-    @fields.depends('invoice', 'date', 'batch', 'amount', 'journal')
+    @fields.depends(
+        'invoice', 'date', 'batch', '_parent_batch.id', 'amount', 'journal')
     def on_change_invoice(self):
         pool = Pool()
         Currency = pool.get('currency.currency')
@@ -743,25 +744,38 @@ class BatchLine(ModelSQL, ModelView):
         return lines
 
     def set_code(self):
-        Sequence = Pool().get('ir.sequence')
+        pool = Pool()
+        Sequence = pool.get('ir.sequence')
+        ModelData = pool.get('ir.model.data')
 
         if not self.code:
+            sequence_type = ModelData.get_id(
+                        'account_batch', 'sequence_type_account_batch_line')
+            sequence, = Sequence.search([
+                    ('sequence_type', '=', sequence_type),
+                    ], limit=1)
             self.write([self], {
-                    'code': Sequence.get('account.batch.line'),
+                    'code': sequence.get(),
                     })
 
     @classmethod
     def create(cls, vlist):
         pool = Pool()
         Sequence = pool.get('ir.sequence')
+        ModelData = pool.get('ir.model.data')
+
+        sequence_type = ModelData.get_id(
+                    'account_batch', 'sequence_type_account_batch_line_create')
+        sequence, = Sequence.search([
+                ('sequence_type', '=', sequence_type),
+                ], limit=1)
 
         lines = super().create(vlist)
         to_write = []
         for line in lines:
-            sequence = Sequence.get('account.batch.line.create')
             move = line.manage_on_create(line)
             to_write.extend([
-                    [line], {'move': move.id, 'sequence': sequence},
+                    [line], {'move': move.id, 'sequence': sequence.get()},
                     ])
         if to_write:
             with Transaction().set_context(skip_update_move=True):
@@ -845,8 +859,10 @@ class BatchLine(ModelSQL, ModelView):
             taxes = self._get_taxes(self.tax)
             base_tax_lines = []
             for tax in taxes:
+                # print('tax', tax.rec_name)
                 if self.tax.reverse_charge:
                     reverse_charge = True
+                # print('reverse charge', reverse_charge)
                 total_amount = base_amount = amount
                 if not self.tax.reverse_charge:
                     base_amount = tax.reverse_compute(amount, [tax])
@@ -876,6 +892,9 @@ class BatchLine(ModelSQL, ModelView):
 
                 tax_group = get_tax_group(tax)
                 tax_group_kind = tax_group.kind if tax_group else None
+                # print('self amount', self.amount)
+                # print('side', side)
+                # print('kind', tax_group_kind)
                 if side == 'credit':
                     tax_debit, tax_credit = -tax_amount, _ZERO
                     tax_account = tax_credit_account
@@ -892,6 +911,8 @@ class BatchLine(ModelSQL, ModelView):
                 if cancel:
                     tax_debit, tax_credit = -tax_debit, -tax_credit
                     tax_tax_amount = -tax_tax_amount
+                # print('tax_debit, tax_credit', tax_debit, tax_credit)
+                # print('base_amount', base_amount)
 
                 # Create the move line for the tax(es)
                 tax_move_line = self._get_move_line(
@@ -910,6 +931,8 @@ class BatchLine(ModelSQL, ModelView):
                 tax_base_amount = abs(base_amount)
                 if tax_tax_amount < _ZERO:
                     tax_base_amount = -tax_base_amount
+                # print('tax_base_amount', tax_base_amount)
+                # print('tax_tax_amount', tax_tax_amount)
                 base_tax_line = self._get_tax_line(tax_base_amount,
                     'base', tax)
                 base_tax_lines.append(base_tax_line)
@@ -932,6 +955,8 @@ class BatchLine(ModelSQL, ModelView):
             if cancel:
                 base_debit, base_credit = -base_debit, -base_credit
                 total_debit, total_credit = -total_debit, -total_credit
+            # print('base_debit, base_credit', base_debit, base_credit)
+            # print('total_debit, total_credit', total_debit, total_credit)
             base_move_line = self._get_move_line(
                 base_debit, base_credit, base_account, second_currency,
                 amount_second_currency)
@@ -954,6 +979,7 @@ class BatchLine(ModelSQL, ModelView):
                         second_currency, amount_second_currency))
             res.append(self._get_move_line(amount, _ZERO, debit_account,
                         second_currency, amount_second_currency))
+        # print(res)
         return res
 
     def _get_move_line(self, debit, credit, account, second_currency,
@@ -970,7 +996,6 @@ class BatchLine(ModelSQL, ModelView):
             second_currency=second_currency,
             amount_second_currency=amount_second_currency,
             maturity_date=self.maturity_date,
-            code=self.sequence,
             reference=self.reference or '',
             origin=self,
             tax_lines=[],
